@@ -1,4 +1,4 @@
-/* $Id: prockernel.h,v 1.23 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: prockernel.h,v 1.25 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -47,8 +47,8 @@ typedef struct _glibtop_proc_kernel	glibtop_proc_kernel;
 
 struct _glibtop_proc_kernel
 {
-	u_int64_t flags;
-	u_int64_t k_flags,	/* kernel flags for the process */
+	guint64 flags;
+	guint64 k_flags,	/* kernel flags for the process */
 		min_flt,	/* number of minor page faults since
 				 * process start */
 		maj_flt,	/* number of major page faults since
@@ -82,16 +82,6 @@ void glibtop_init_proc_kernel_s (glibtop *server);
 void glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_kernel [];
-extern const unsigned glibtop_types_proc_kernel [];
-extern const char *glibtop_labels_proc_kernel [];
-extern const char *glibtop_descriptions_proc_kernel [];
-
-#endif
 
 G_END_DECLS
 
